@@ -59,11 +59,11 @@ class CLI(cl1.CLI):
 
 		# help.
 		if self.arguments.present(['-h', '--help']):
-			self.docs(success=True, json=syst3m.defauts.options.json)
+			self.docs(success=True, json=syst3m.defaults.options.json)
 
 		# version.
 		elif self.arguments.present(['--version']):
-			print(f"{ALIAS} version:",Files.load(f"{SOURCE_PATH}/.version").replace("\n",""))
+			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version").replace("\n",""), json=syst3m.defaults.options.json)
 
 		# config.
 		#elif self.arguments.present('--config'):
@@ -72,14 +72,6 @@ class CLI(cl1.CLI):
 		#	else:
 		#		os.system(f"nano {CONFIG.file_path.path}")
 
-		# clear logs.
-		if not self.arguments.present(['-c']):
-			os.system("clear")
-
-		# help.
-		if self.arguments.present(['-h', '--help']):
-			print(self.documentation)
-
 		# user.
 		elif self.arguments.present(['--user']):
 			syst3m.defaults.operating_system(supported=["linux"])
@@ -91,7 +83,7 @@ class CLI(cl1.CLI):
 			if self.arguments.present(['--check']):
 				response = user.check()
 				r3sponse.log(response)
-				if r3sponse.success(response): print("User existance:",response["exists"])
+				if response.success: print("User existance:",response["exists"])
 
 			# create a user.
 			elif self.arguments.present(['--create']):
@@ -136,7 +128,7 @@ class CLI(cl1.CLI):
 			if self.arguments.present(['--check']):
 				response = group.check()
 				r3sponse.log(response)
-				if r3sponse.success(response): 
+				if response.success: 
 					print("Group existance:",response["exists"])
 
 			# create a group.
@@ -153,7 +145,7 @@ class CLI(cl1.CLI):
 			elif self.arguments.present(['--list-users']):
 				response = group.list_users()
 				r3sponse.log(response)
-				if r3sponse.success(response): 
+				if response.success: 
 					print(f"Users of group {group.name}:",response["users"])
 
 			# add users to the group.
@@ -207,7 +199,7 @@ class CLI(cl1.CLI):
 				print(f"Size {fp.path}: {size}")
 
 		# invalid.
-		else:  self.invalid()
+		else: self.invalid(json=syst3m.defaults.options.json)
 
 		#
 	def get_password(self, retrieve=False, check=False, message="Password:"):
