@@ -99,11 +99,11 @@ class WebServer(objects.Thread):
 		try:
 			response = requests.get(f'http://{self.host}:{self.port}/set?{encoded}', timeout=timeout)
 		except Exception as e:
-			return r3sponse.error_response(f"Failed to connect with {self.host}:{self.port}, error: {e}")
+			return r3sponse.error(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
 			response = self.__serialize__(response.json())
 		except:
-			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
+			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
 		return r3sponse.safe_response(response)
 	def get(self, group=None, id=None, timeout=3):
 		encoded = urllib.parse.urlencode({
@@ -116,11 +116,11 @@ class WebServer(objects.Thread):
 		try:
 			response = requests.get(f'http://{self.host}:{self.port}/get?{encoded}', timeout=timeout)
 		except Exception as e:
-			return r3sponse.error_response(f"Failed to connect with {self.host}:{self.port}, error: {e}")
+			return r3sponse.error(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
 			response = self.__serialize__(response.json())
 		except:
-			return r3sponse.error_response(f"Failed to serialize {response}: {response.text}")
+			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
 		return r3sponse.safe_response(response)
 	def app(self):
 		app = flask.Flask(__name__)
@@ -130,7 +130,7 @@ class WebServer(objects.Thread):
 		def get():
 			token = flask.request.args.get('token')
 			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
-				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+				return r3sponse.error(f"Provided an invalid token {token}.").json()
 			group = flask.request.args.get('group')
 			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
@@ -142,8 +142,8 @@ class WebServer(objects.Thread):
 					tag = f"{group}:{id}"
 					value = self.cache[group][id]
 			except KeyError:
-				return r3sponse.error_response(f"There is no data cached for {tag}.").json()
-			return r3sponse.success_response(f"Successfully retrieved {tag}.", {
+				return r3sponse.error(f"There is no data cached for {tag}.").json()
+			return r3sponse.success(f"Successfully retrieved {tag}.", {
 				"group":group,
 				"id":id,
 				"data":value,
@@ -152,7 +152,7 @@ class WebServer(objects.Thread):
 		def set():
 			token = flask.request.args.get('token')
 			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
-				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+				return r3sponse.error(f"Provided an invalid token {token}.").json()
 			group = flask.request.args.get('group')
 			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
@@ -165,13 +165,13 @@ class WebServer(objects.Thread):
 				try: self.cache[group]
 				except KeyError: self.cache[group] = {}
 				self.cache[group][id] = value
-			return r3sponse.success_response(f"Successfully cached {tag}.").json()
+			return r3sponse.success(f"Successfully cached {tag}.").json()
 		@app.route('/active')
 		def active():
 			token = flask.request.args.get('token')
 			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
-				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
-			return r3sponse.success_response(f"Active.").json()
+				return r3sponse.error(f"Provided an invalid token {token}.").json()
+			return r3sponse.success(f"Active.").json()
 		#def run__(self, app, host, port):
 		#	app.run(host=host, port=port)
 		#self.process = multiprocessing.Process(target=app.run, args=(self, app, self.host,self.port,))
@@ -199,7 +199,7 @@ class WebServer(objects.Thread):
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
 	def fork(self, timeout=15, sleeptime=1):
 		if self.running():
-			return r3sponse.error_response(f"The {self.id} is already running.")
+			return r3sponse.error(f"The {self.id} is already running.")
 		if self.log_level <= 0:
 			print(f"Starting the {self.id}.")
 		serialized = self.dict()
@@ -218,21 +218,21 @@ class WebServer(objects.Thread):
 				break
 			time.sleep(sleeptime)
 		if success:
-			return r3sponse.success_response(f"Successfully started the {self.id}.")
+			return r3sponse.success(f"Successfully started the {self.id}.")
 		else:
-			return r3sponse.error_response(f"The {self.id} is already running.")
+			return r3sponse.error(f"The {self.id} is already running.")
 	def stop(self):
 		if not self.running(): 
-			return r3sponse.error_response(f"The {self.id} is not running.")
+			return r3sponse.error(f"The {self.id} is not running.")
 		processes = processes(includes=f"--syst3m-webserver-tag {self.tag}")
 		if not processes.success: return response
 		if len(processes.processes) <= 1:
-			return r3sponse.error_response(f"Unable to find the pid of the {self.id}.")
+			return r3sponse.error(f"Unable to find the pid of the {self.id}.")
 		for pid, info in processes.processes.items():
 			if info["process"] not in ["grep"]:
 				response = kill(pid=pid)
 				if not response.success: return response
-		return r3sponse.error_response(f"Successfully stopped the {self.id}.")
+		return r3sponse.error(f"Successfully stopped the {self.id}.")
 	def __serialize__(self, dict, safe=False):
 		for key in list(dict.keys()):
 			value = dict[key]
