@@ -60,7 +60,7 @@ def __check_alias__(
 		sys.exit(0)
 
 # source.
-from fil3s import Formats
+from fil3s import *
 ALIAS = "syst3m"
 SOURCE_NAME = "syst3m"
 SOURCE_PATH = Formats.FilePath(__file__).base(back=3)
@@ -74,7 +74,7 @@ try:
 
 	# inc imports.
 	import cl1
-	from fil3s import Files, Formats
+	from fil3s import *
 	from r3sponse import r3sponse
 
 # download.
@@ -90,9 +90,12 @@ except ImportError as e:
 
 	# inc imports.
 	import cl1
-	from fil3s import Files, Formats
+	from fil3s import *
 	from r3sponse import r3sponse
 
+# version.
+version = Files.load(f"{SOURCE_PATH}/.version")
+
 # universal variables.
 USER = os.environ.get("USER")
 OWNER = os.environ.get("USER")
