@@ -31,6 +31,10 @@ def execute(
 	command="ls .",
 	# joiner for when command is in list format.
 	joiner="\n",
+	# serialize to dict. (r3sponse.ResponseObject) (slice first dict).
+	serialize=False,
+	# the executive.
+	executive="sh",
 ):
 	path = f"/tmp/tmp_script_{Formats.String('').generate()}"
 	if isinstance(command, list):
@@ -38,7 +42,7 @@ def execute(
 	Files.save(path, command)
 	try:
 		proc = subprocess.run(
-		    ["sh", path],
+		    [executive, path],
 			check=True,
 			capture_output=True,
 			text=True,
@@ -55,11 +59,18 @@ def execute(
 		return r3sponse.error(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
 	if len(output) > 0 and output[len(output)-1] == "\n": output = output[:-1]
 	Files.delete(path)
-	return r3sponse.success(f"Succesfully executed command ({command}), (output: {output}), (error: {error_}).", {
-		"output":output,
-		"pid":process.pid,
-		"process":proc,
-	})
+	if serialize:
+		try: response = r3sponse.ResponseObject(json=output)
+		except Exception as e: 
+			if loader != None: loader.stop(success=False)
+			return r3sponse.error(f"Failed to serialize output: {output}")
+		return response
+	else:
+		return r3sponse.success(f"Succesfully executed command ({command}), (output: {output}), (error: {error_}).", {
+			"output":output,
+			"process":proc,
+			#"pid":proc.pid, # only for subprocess.Popen
+		})
 
 # the loader object class.
 class Loader(threading.Thread):
